/*******************************************************************************
 *  PROJECT: GNOME Colorscheme
 *
 *  AUTHOR: Jonathon Jongsma
 *
 *  Copyright (c) 2005 Jonathon Jongsma
 *
 *  License:
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the 
 *    Free Software Foundation, Inc., 59 Temple Place, Suite 330, 
 *    Boston, MA  02111-1307  USA
 *
 *******************************************************************************/

#ifndef __GCS_PALETTE_H
#define __GCS_PALETTE_H

#include <vector>
#include <istream>

#include <gtkmm/button.h>
#include <gtkmm/table.h>
#include <gtkmm/scrolledwindow.h>
#include <gtkmm/expander.h>
#include <glibmm/ustring.h>
#include <libgnomevfsmm/uri.h>

#include "gcs-color.h"
#include "gcs-types.h"

namespace gcs
{
    class Palette
    {
        public:
            Palette(Glib::RefPtr<Gnome::Vfs::Uri> file);
            //~Palette();

            bool set_from_file(Glib::ustring filename);
            bool set_from_string(Glib::ustring& palette_def);
            Glib::ustring get_name(void) const { return m_name; }
            gint size(void) { return m_colors.size(); }
            Glib::ustring get_name(void) { return m_name; }
            gint get_columns(void) { return m_columns; }
            ColorPtr operator[](gint idx) { return m_colors[idx]; }
            // deletes all the colors and clears m_colors
            void reset(void);

#ifdef UNIT_TEST
            friend class PaletteTests;
#endif

        protected:
            bool parse_palette(std::istream& i);
            // only for parsing lines that actually define a color -- not
            // for header lines like "Name: xxx"
            static ColorPtr parse_line(Glib::ustring palette_line);

            Glib::ustring m_name;
            std::vector<ColorPtr> m_colors;
            gint m_columns;
    };

} // namespace gcs

#endif // __GCS_PALETTE_H
