/*******************************************************************************
 *  PROJECT: GNOME Colorscheme
 *
 *  AUTHOR: Jonathon Jongsma
 *
 *  Copyright (c) 2005 Jonathon Jongsma
 *
 *  License:
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the 
 *    Free Software Foundation, Inc., 59 Temple Place, Suite 330, 
 *    Boston, MA  02111-1307  USA
 *
 *******************************************************************************/

#ifndef __GCS_BOOKMARKLIST_H
#define __GCS_BOOKMARKLIST_H

#include <gtkmm/treeview.h>
#include <gtkmm/liststore.h>
#include <libgnomevfsmm/uri.h>

#include "../core/gcs-color.h"
#include "../core/gcs-palette.h"
#include "../core/gcs-types.h"

namespace gcs
{
    namespace Widgets
    {
        class BookmarkList : public Gtk::TreeView, public gcs::Palette
        {
            public:
                BookmarkList(Glib::RefPtr<Gnome::Vfs::Uri> fUri);
                void add(ColorPtr clr);
                void clear(void);
                ColorPtr get_color(void);
                bool empty(void);
                void remove_selected(void);
                gint count_selected(void);

            private:
                void load_from_file(void);
                void save_to_disk(void);

                // This is an 'internal' add function that doesn't update the
                // file on disk.  It simply adds the Color to the UI list -- no
                // checking for duplicates or anything else.  used by add()
                void add_(ColorPtr clr);

                class ModelColumns : public Gtk::TreeModel::ColumnRecord
                {
                    public:
                        ModelColumns() { add(m_colColor); add(m_colText); }
                        Gtk::TreeModelColumn<ColorPtr> m_colColor;
                        Gtk::TreeModelColumn<tHexString> m_colText;
                };

                ModelColumns m_columns;
                Glib::RefPtr<Gtk::ListStore> m_refListStore;
                Glib::RefPtr<Gnome::Vfs::Uri> m_file;
        };

    } // namespace Widgets
} // namespace gcs

#endif // __GCS_BOOKMARKLIST_H
