/*******************************************************************************
 *  PROJECT: GNOME Colorscheme
 *
 *  AUTHOR: Jonathon Jongsma
 *
 *  Copyright (c) 2005 Jonathon Jongsma
 *
 *  License:
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the 
 *    Free Software Foundation, Inc., 59 Temple Place, Suite 330, 
 *    Boston, MA  02111-1307  USA
 *
 *******************************************************************************/

#ifndef __GCS_PALETTEVIEW_H
#define __GCS_PALETTEVIEW_H

#include <vector>
#include <istream>

#include <gtkmm/table.h>
#include <gtkmm/scrolledwindow.h>
#include <gtkmm/expander.h>
#include <glibmm/ustring.h>
#include <libgnomevfsmm/uri.h>

#include "../core/gcs-types.h"
#include "../core/gcs-color.h"
#include "../core/gcs-palette.h"

namespace gcs
{
    namespace Widgets
    {
        class PaletteView : public Gtk::Expander
        {
            public:
                PaletteView(Glib::RefPtr<Gnome::Vfs::Uri> uri);
                //~PaletteView();
                bool set_from_file(Glib::ustring fname);

                sigc::signal<void, tHexString>& signal_color_selected() {
                    return m_signal_color_selected; }

#ifdef UNIT_TEST
                friend class PaletteTests;
#endif

            protected:
                Gtk::Table m_table;
                bool on_color_selected(gint index);
                void reset(void);
                void populate(void);

            private:
                Gtk::ScrolledWindow m_scrolledWindow;
                sigc::signal<void, tHexString> m_signal_color_selected;
                boost::shared_ptr<Palette> m_palette;
                static const gint m_minCellSize;
                static const gint m_minPaletteWidth;
                static const gint m_maxPaletteHeight;
                gint m_rows;
        };

    } // namespace Widgets
} // namespace gcs

#endif // __GCS_PALETTEVIEW_H
